@@ -1,7 +1,7 @@
 /*
     FLVMeta - FLV Metadata Editor
 
-    Copyright (C) 2007-2016 Marc Noirot <marc.noirot AT gmail.com>
+    Copyright (C) 2007-2019 Marc Noirot <marc.noirot AT gmail.com>
 
     This file is part of FLVMeta.
 
@@ -31,8 +31,6 @@ static void amf_data_yaml_dump(const amf_data * data, yaml_emitter_t * emitter)
     if (data != NULL) {
         amf_node * node;
         yaml_event_t event;
-        time_t time;
-        struct tm * t;
         char str[128];
 
         switch (data->type) {
@@ -101,10 +99,7 @@ static void amf_data_yaml_dump(const amf_data * data, yaml_emitter_t * emitter)
                 yaml_emitter_emit(emitter, &event);
                 break;
             case AMF_TYPE_DATE:
-                time = amf_date_to_time_t(data);
-                tzset();
-                t = localtime(&time);
-                strftime(str, sizeof(str), "%Y-%m-%dT%H:%M:%S", t);
+                amf_date_to_iso8601(data, str, sizeof(str));
                 yaml_scalar_event_initialize(&event, NULL, NULL, (yaml_char_t*)str, (int)strlen(str), 1, 1, YAML_ANY_SCALAR_STYLE);
                 yaml_emitter_emit(emitter, &event);
                 break;
@@ -373,7 +368,7 @@ static int yaml_on_audio_tag(flv_tag * tag, flv_audio_tag at, flv_parser * parse
     return OK;
 }
 
-static int yaml_on_metadata_tag(flv_tag * tag, amf_data * name, amf_data * data, flv_parser * parser) {
+static int yaml_on_metadata_tag(flv_tag * tag, char * name, amf_data * data, flv_parser * parser) {
     yaml_emitter_t * emitter;
     yaml_event_t event;
 
@@ -415,17 +410,17 @@ static int yaml_on_stream_end(flv_parser * parser) {
 }
 
 /* YAML FLV file metadata dump callbacks */
-static int yaml_on_metadata_tag_only(flv_tag * tag, amf_data * name, amf_data * data, flv_parser * parser) {
+static int yaml_on_metadata_tag_only(flv_tag * tag, char * name, amf_data * data, flv_parser * parser) {
     flvmeta_opts * options = (flvmeta_opts*) parser->user_data;
 
     if (options->metadata_event == NULL) {
-        if (!strcmp((char*)amf_string_get_bytes(name), "onMetaData")) {
+        if (!strcmp(name, "onMetaData")) {
             dump_yaml_amf_data(data);
             return FLVMETA_DUMP_STOP_OK;
         }
     }
     else {
-        if (!strcmp((char*)amf_string_get_bytes(name), options->metadata_event)) {
+        if (!strcmp(name, options->metadata_event)) {
             dump_yaml_amf_data(data);
         }
     }
